@@ -2,11 +2,11 @@ package File::Gettext;
 
 use 5.010001;
 use namespace::autoclean;
-use version; our $VERSION = qv( sprintf '0.29.%d', q$Rev: 1 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.30.%d', q$Rev: 1 $ =~ /\d+/gmx );
 
 use English                    qw( -no_match_vars );
 use File::DataClass::Constants qw( EXCEPTION_CLASS FALSE NUL SPC TRUE );
-use File::DataClass::Functions qw( throw );
+use File::DataClass::Functions qw( is_hashref merge_attributes throw );
 use File::DataClass::IO        qw( io );
 use File::DataClass::Types     qw( ArrayRef Directory HashRef Str Undef );
 use File::Gettext::Constants   qw( LOCALE_DIRS );
@@ -19,9 +19,7 @@ extends q(File::DataClass::Schema);
 
 # Private functions
 my $_build_localedir = sub {
-   my $dir = shift;
-
-   my $io; $dir and $io = io( $dir ) and $io->is_dir and return $io;
+   my $dir = shift; $dir and $dir = io( $dir ) and $dir->is_dir and return $dir;
 
    for $dir (map { io $_ } @{ LOCALE_DIRS() }) {
       $dir->exists and $dir->is_dir and return $dir;
@@ -40,8 +38,6 @@ coerce $LocaleDir,
 my $SourceType = enum 'SourceType' => [ 'mo', 'po' ];
 
 # Public attributes
-has 'catagory_name'     => is => 'ro', isa => Str, default => 'LC_MESSAGES';
-
 has 'charset'           => is => 'ro', isa => Str, default => 'iso-8859-1';
 
 has 'default_po_header' => is => 'ro', isa => HashRef,
@@ -53,6 +49,8 @@ has 'default_po_header' => is => 'ro', isa => HashRef,
       team              => 'Translators',
       translator        => 'Athena', } };
 
+has 'gettext_catagory'  => is => 'ro', isa => Str, default => 'LC_MESSAGES';
+
 has 'header_key_table'  => is => 'ro', isa => HashRef,
    default              => sub { {
       project_id_version        => [ 0,  'Project-Id-Version'        ],
@@ -92,15 +90,28 @@ has 'source_name'    => is => 'ro', isa => $SourceType,
 my $_is_file_or_log_debug = sub {
    my ($self, $path) = @_;
 
-   $path->exists or ($self->log->debug( 'Path '.$path->pathname.' not found' )
-                     and return FALSE);
-   $path->is_file    and return TRUE;
+   $path->exists  or ($self->log->debug( 'Path '.$path->pathname.' not found' )
+                      and return FALSE);
+   $path->is_file or ($self->log->debug( 'Path '.$path->pathname.' not a file' )
+                      and return FALSE);
 
-   $self->log->debug( 'Path '.$path->pathname.' not a file' );
-   return FALSE;
+   return TRUE;
 };
 
 # Construction
+around 'BUILDARGS' => sub {
+   my ($orig, $self, @args) = @_; my $attr = $orig->( $self, @args );
+
+   my $builder = $attr->{builder} or return $attr;
+   my $config  = $builder->can( 'config' ) ? $builder->config : {};
+   my $keys    = [ 'gettext_catagory', 'localedir' ];
+
+   merge_attributes $attr, $builder, $keys;
+   merge_attributes $attr, $config,  $keys;
+
+   return $attr;
+};
+
 around 'source' => sub {
    my ($orig, $self) = @_; return $orig->( $self, $self->source_name );
 };
@@ -110,13 +121,16 @@ around 'resultset' => sub {
 };
 
 around 'load' => sub {
-   my ($orig, $self, $lang, @names) = @_;
+   my ($orig, $self, $lang, @files) = @_;
 
-   my @paths     = grep { $self->$_is_file_or_log_debug( $_ ) }
-                   map  { $self->get_lang_file( $lang, $_ ) } @names;
-   my $data      = $orig->( $self, @paths );
+   my @paths = grep { $self->$_is_file_or_log_debug( $_ ) }
+               map  { $self->object_file( $lang, $_ ) } @files;
+
+   not $paths[ 0 ] and not $self->path and return {};
+
+   my $data  = $orig->( $self, @paths );
    my $po_header = exists $data->{po_header}
-                 ? $data->{po_header}->{msgstr} || {} : {};
+                 ? $data->{po_header}->{msgstr} // {} : {};
    my $plural_func;
 
    # This is here because of the code ref. Cannot serialize (cache) a code ref
@@ -139,7 +153,7 @@ around 'load' => sub {
    }
 
    # Default is Germanic plural (which is incorrect for French).
-   $data->{plural_func} = $plural_func || sub { (2, shift > 1) };
+   $data->{plural_func} = $plural_func // sub { (2, shift > 1) };
 
    return $data;
 };
@@ -154,17 +168,21 @@ sub _trigger_source_name {
 }
 
 # Public methods
-sub get_lang_file {
-   my ($self, $lang, $file) = @_; my $extn = $self->storage->extn;
+sub object_file {
+   my ($self, $lang, $file) = @_;
 
    $lang or throw Unspecified, [ 'language' ];
-   $file or throw Unspecified, [ 'language file path' ];
+   $file or throw Unspecified, [ 'language file name' ];
 
-   return $self->localedir->catfile( $lang, $self->catagory_name, $file.$extn );
+   my $dir = $self->localedir; my $extn = $self->storage->extn;
+
+   length $self->gettext_catagory or return $dir->catfile( $lang, $file.$extn );
+
+   return $dir->catfile( $lang, $self->gettext_catagory, $file.$extn );
 }
 
 sub set_path {
-   my $self = shift; return $self->path( $self->get_lang_file( @_ ) );
+   my $self = shift; return $self->path( $self->object_file( @_ ) );
 }
 
 1;
@@ -173,9 +191,12 @@ __END__
 
 =pod
 
+=encoding utf-8
+
 =begin html
 
 <a href="https://travis-ci.org/pjfl/p5-file-gettext"><img src="https://travis-ci.org/pjfl/p5-file-gettext.svg?branch=master" alt="Travis CI Badge"></a>
+<a href="https://roxsoft.co.uk/coverage/report/file-gettext/latest"><img src="https://roxsoft.co.uk/coverage/badge/file-gettext/latest" alt="Coverage Badge"></a>
 <a href="http://badge.fury.io/pl/File-Gettext"><img src="https://badge.fury.io/pl/File-Gettext.svg" alt="CPAN Badge"></a>
 <a href="http://cpants.cpanauthors.org/dist/File-Gettext"><img src="http://cpants.cpanauthors.org/dist/File-Gettext.png" alt="Kwalitee Badge"></a>
 
@@ -187,13 +208,13 @@ File::Gettext - Read and write GNU Gettext po / mo files
 
 =head1 Version
 
-This documents version v0.29.$Rev: 1 $ of L<File::Gettext>
+This documents version v0.30.$Rev: 1 $ of L<File::Gettext>
 
 =head1 Synopsis
 
    use File::Gettext;
 
-   my $domain = File::Gettext->new( $attrs )->load( $lang, @names );
+   my $domain = File::Gettext->new( $attrs )->load( $lang, @files );
 
 =head1 Description
 
@@ -208,11 +229,6 @@ Defines the following attributes;
 
 =over 3
 
-=item C<catagory_name>
-
-Subdirectory of C<localdir> that contains the F<mo> / F<po> files. Defaults
-to C<LC_MESSAGES>
-
 =item C<charset>
 
 Default character set used it the F<mo> / F<po> does not specify one. Defaults
@@ -222,6 +238,12 @@ to C<iso-8859-1>
 
 Default header information used to create new F<po> files
 
+=item C<gettext_catagory>
+
+Subdirectory of a language specific subdirectory of L</localdir> that contains
+the F<mo> / F<po> files. Defaults to C<LC_MESSAGES>. Can be set to the null
+string to eliminate from path
+
 =item C<header_key_table>
 
 Maps attribute header names onto their F<po> file header strings
@@ -242,28 +264,32 @@ Either F<po> or F<mo>. Defaults to F<po>
 
 =head1 Subroutines/Methods
 
-=head2 get_lang_file
+=head2 C<BUILDARGS>
 
-   $gettext->get_lang_file( $lang, $file );
+Extracts default attribute values from the C<builder> parameter
 
-Returns the path to the po/mo file for the specified language
-
-=head2 load
+=head2 C<load>
 
 This method modifier adds the pluralisation function to the return data
 
-=head2 resultset
+=head2 C<object_file>
+
+   $gettext->object_file( $lang, $file );
+
+Returns the path to the F<po> / F<mo> file for the specified language
+
+=head2 C<resultset>
 
 A method modifier that provides the result source name to the same method
 in the parent class
 
-=head2 set_path
+=head2 C<set_path>
 
    $gettext->set_path( $lang, $file );
 
 Sets the I<path> attribute on the parent class from C<$lang> and C<$file>
 
-=head2 source
+=head2 C<source>
 
 A method modifier that provides the result source name to the same method
 in the parent class
@@ -302,7 +328,7 @@ Peter Flanigan, C<< <pjfl@cpan.org> >>
 
 =head1 License and Copyright
 
-Copyright (c) 2015 Peter Flanigan. All rights reserved
+Copyright (c) 2016 Peter Flanigan. All rights reserved
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>
